---
title: "{{project_title}}"
author: "{{author}}"
bibliography: [data/records.bib,data/data/non_sample_references.bib]
figPrefix: "Figure"
tblPrefix: "Table"
csl: "https://raw.githubusercontent.com/citation-style-language/styles/master/apa.csl"
---

# Abstract

**Keywords**: keyword 1; keyword 2; {{review_type}}.

# Introduction

# Background

# Methodology

Data was managed with CoLRev version {{colrev_version}} [@WagnerPrester2022].

# Synthesis

# Discussion

# Conclusion

<!--
# Appendix

## Declarations

## List of contributors

## Project timeline

## Software tools

## Publication plan
 -->

# Coding and synthesis

<!-- NEW_RECORD_SOURCE -->

# References
